#
# Conditional build:
%bcond_without	static_libs	# don't build static libraries
%bcond_with	tests		# build with tests

Summary:	Library of C++11 components designed with practicality and efficiency in mind
Name:		folly
Version:	0.41.0
Release:	1
License:	Apache v2.0
Group:		Libraries
Source0:	https://github.com/facebook/folly/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	d7ff7682850ea0846881fb1fb42136e9
URL:		https://github.com/facebook/folly
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	boost-devel >= 1.20.0
BuildRequires:	double-conversion-devel
BuildRequires:	gflags-devel
BuildRequires:	glog-devel
%{?with_tests:BuildRequires:	gtest-devel >= 1.6.0}
BuildRequires:	libevent-devel
BuildRequires:	libstdc++-devel
BuildRequires:	libtool
BuildRequires:	m4
BuildRequires:	openssl-devel
BuildRequires:	python
BuildRequires:	python-modules
BuildRequires:	rpmbuild(macros) >= 1.583
ExclusiveArch:	%{x8664}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		sover	%(echo %{version} | cut -d. -f2)

# missing openssl linking
%define		skip_post_check_so	libfolly.so.%{sover}.0.0

%description
Folly (acronymed loosely after Facebook Open Source Library) is a
library of C++11 components designed with practicality and efficiency
in mind. It complements (as opposed to competing against) offerings
such as Boost and of course std. In fact, we embark on defining our
own component only when something we need is either not available, or
does not meet the needed performance profile.

Performance concerns permeate much of Folly, sometimes leading to
designs that are more idiosyncratic than they would otherwise be (see
e.g. PackedSyncPtr.h, SmallLocks.h). Good performance at large scale
is a unifying theme in all of Folly.

%package devel
Summary:	Header files for %{name} library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for %{name} library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki %{name}.

%package static
Summary:	Static %{name} library
Summary(pl.UTF-8):	Statyczna biblioteka %{name}
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static %{name} library.

%description static -l pl.UTF-8
Statyczna biblioteka %{name}.

%prep
%setup -q

#ln -s %{_usrsrc}/gtest folly/test/gtest-1.7.0

%build
cd folly
%{__libtoolize}
%{__aclocal}
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{!?with_static_libs:--disable-static}
%{__make}
%{?with_tests:%{__make} check}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} -C folly install \
	DESTDIR=$RPM_BUILD_ROOT

# these aren't supposed to be installed!
#rm $RPM_BUILD_ROOT%{_libdir}/libgtest*

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc README.md LICENSE
%attr(755,root,root) %{_libdir}/libfolly.so.*.*.*
%ghost %{_libdir}/libfolly.so.%{sover}
%attr(755,root,root) %{_libdir}/libfollybenchmark.so.*.*.*
%ghost %{_libdir}/libfollybenchmark.so.%{sover}

%files devel
%defattr(644,root,root,755)
%{_libdir}/libfolly.so
%{_libdir}/libfollybenchmark.so
%{_libdir}/libfolly.la
%{_libdir}/libfollybenchmark.la
%{_includedir}/folly

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libfolly.a
%{_libdir}/libfollybenchmark.a
%endif
%changelog
* Sun Aug 02 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/folly.git;a=log;h=master

* Wed Jul 29 2015 Elan Ruusamäe <glen@delfi.ee> 98eebf8
- up to 0.41.0, add tests bcond

* Wed Jun 10 2015 Jan Rękorajski <baggins@pld-linux.org> 003db87
- release 2 (by relup.sh)

* Mon Apr 06 2015 Elan Ruusamäe <glen@delfi.ee> c09b0dc
- update BR

* Fri Mar 20 2015 Elan Ruusamäe <glen@delfi.ee> d4b1216
- up to 0.31.0

* Mon Feb 09 2015 Elan Ruusamäe <glen@delfi.ee> 94baf25
- better summary

* Mon Oct 07 2013 Elan Ruusamäe <glen@delfi.ee> a810199
- install more headers, used by hiphop-php

* Sun Oct 06 2013 Elan Ruusamäe <glen@delfi.ee> 423f0b7
- 32bit arch not supported (uses 64bit integers that get truncated on 32bit)

* Sun Oct 06 2013 Elan Ruusamäe <glen@delfi.ee> 75aeafe
- uses static double-conversion lib

* Sun Oct 06 2013 Elan Ruusamäe <glen@delfi.ee> 3a55340
- BR: glog-devel

* Sun Oct 06 2013 Elan Ruusamäe <glen@delfi.ee> a801c47
- install more headers, used by hiphop-php

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> 4c898fa
- version 0.1 from configure.ac is correct. enhanced desc and added more specific url

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> 987f958
- new, version unknown so calling it 0.1

